@@ -2,12 +2,9 @@ use warnings;
 use strict;
 
 package Data::ICal::Entry;
-use base qw/Class::Accessor/;
 use Data::ICal::Property;
 use Carp;
 
-use constant CRLF => "\x0d\x0a";
-
 =head1 NAME
 
 Data::ICal::Entry - Represents an entry in an iCalendar file
@@ -17,7 +14,7 @@ Data::ICal::Entry - Represents an entry in an iCalendar file
 
     my $vtodo = Data::ICal::Entry::Todo->new();
     $vtodo->add_properties(
-    # ... see Data::ICal::Entry::Todo documentation
+	# ... see Data::ICal::Entry::Todo documentation
     );
 
     $calendar->add_entry($vtodo);
@@ -52,37 +49,30 @@ Creates a new entry object with no properties or sub-entries.
 
 sub new {
     my $class = shift;
-    my $self = $class->SUPER::new;
-    $self->set(properties => {});
-    $self->set(entries => []);
+    my $self  = {
+        properties => {},
+        entries    => [],
+    };
+    bless $self, $class;
     return $self;
 }
 
-=head2 as_string [ crlf => C<CRLF> ]
+=head2 as_string
 
-Returns the entry as an appropriately formatted string (with trailing
-newline).
+Returns the entry as an appropriately formatted string (with trailing newline).
 
-Properties are returned in alphabetical order, with multiple
-properties of the same name returned in the order added.  (Property
-order is unimportant in iCalendar, and this makes testing easier.)
+Properties are returned in alphabetical order, with multiple properties of the same name
+returned in the order added.  (Property order is unimportant
+in iCalendar, and this makes testing easier.)
 
 If any mandatory property is missing, issues a warning.
 
-The string to use as a newline can optionally be specified by giving
-the a C<crlf> argument, which defaults to C<\x0d\x0a>, per RFC 2445
-spec; this option is primarily for backwards compatability with
-versions of this module before 0.16.
-
 =cut
 
 sub as_string {
     my $self = shift;
-    my %args = (
-        crlf => CRLF,
-        @_
-    );
-    my $output = $self->header(%args);
+
+    my $output = $self->header;
 
     for my $name (
         $self->mandatory_unique_properties,
@@ -96,13 +86,13 @@ sub as_string {
 
     for my $name ( sort keys %{ $self->properties } ) {
         $output .= $_
-            for map { $_->as_string(%args) } @{ $self->properties->{$name} };
+            for map { $_->as_string } @{ $self->properties->{$name} };
     }
 
     for my $entry ( @{ $self->entries } ) {
-        $output .= $entry->as_string(%args);
+        $output .= $entry->as_string;
     }
-    $output .= $self->footer(%args);
+    $output .= $self->footer;
 
     return $output;
 }
@@ -123,8 +113,6 @@ sub add_entry {
     my $entry = shift;
     push @{ $self->{entries} }, $entry;
 
-    $entry->vcal10( $self->vcal10 );
-
     return 1;
 }
 
@@ -134,7 +122,10 @@ Returns a reference to the array of subentries of this entry.
 
 =cut
 
-__PACKAGE__->mk_ro_accessors('entries');
+sub entries {
+    my $self = shift;
+    return $self->{'entries'};
+}
 
 =head2 properties
 
@@ -143,18 +134,9 @@ the values are array references containing L<Data::ICal::Property> objects.
 
 =cut
 
-__PACKAGE__->mk_ro_accessors('properties');
-
-=head2 property
-
-Given a property name returns a reference to the array of L<Data::ICal::Property> objects.
-
-=cut
-
-sub property {
+sub properties {
     my $self = shift;
-    my $prop = lc shift;
-    return $self->{'properties'}->{$prop};
+    return $self->{'properties'};
 }
 
 =head2 add_property $propname => $propval
@@ -173,11 +155,6 @@ The keys of the hash are parameter names; the values should be either strings or
 of strings, depending on whether the parameter should have one or multiple (to be comma-separated)
 values.
 
-Examples of setting parameters:
-
- # Add a property with a parameter of VALUE set to 'DATE'
- $event->add_property( rdate => [ $date, { VALUE => 'DATE' } ] );
-
 =cut
 
 sub add_property {
@@ -185,9 +162,6 @@ sub add_property {
     my $prop = lc shift;
     my $val  = shift;
 
-
-    return unless defined $prop;
-    
     unless ( $self->is_property($prop) or $prop =~ /^x-/i ) {
         carp "Unknown property for " . ( ref $self ) . ": $prop";
     }
@@ -202,10 +176,8 @@ sub add_property {
 
     my ( $prop_value, $param_hash ) = @$val;
 
-    my $p = Data::ICal::Property->new( $prop => $prop_value, $param_hash );
-    $p->vcal10( $self->vcal10 );
-    
-    push @{ $self->properties->{$prop} }, $p;
+    push @{ $self->properties->{$prop} },
+        Data::ICal::Property->new( $prop => $prop_value, $param_hash );
 }
 
 =head2 add_properties $propname1 => $propval1, [$propname2 => $propname2, ...]
@@ -356,17 +328,6 @@ Subclasses should override this method to provide the identifying type name of t
 
 sub ical_entry_type {'UNDEFINED'}
 
-=head2 vcal10 [$bool]
-
-Gets or sets a boolean saying whether this entry should be interpreted as vCalendar
-1.0 (as opposed to iCalendar 2.0).  Generally, you can just set this on your
-main L<Data::ICal> object when you construct it; C<add_entry> automatically makes
-sure that sub-entries end up with the same value as their parents.
-
-=cut
-
-__PACKAGE__->mk_accessors('vcal10');
-
 =head2 header
 
 Returns the header line for the entry (including trailing newline).
@@ -375,11 +336,7 @@ Returns the header line for the entry (including trailing newline).
 
 sub header {
     my $self = shift;
-    my %args = (
-        crlf => CRLF,
-        @_
-    );
-    return 'BEGIN:' . $self->ical_entry_type . $args{crlf};
+    return 'BEGIN:' . $self->ical_entry_type . "\n";
 }
 
 =head2 footer
@@ -390,149 +347,12 @@ Returns the footer line for the entry (including trailing newline).
 
 sub footer {
     my $self = shift;
-    my %args = (
-        crlf => CRLF,
-        @_
-    );
-    return 'END:' . $self->ical_entry_type . $args{crlf};
-}
-
-# mapping of event types to class (under the Data::Ical::Event namespace)
-my %_generic = (
-    vevent    => 'Event',
-    vtodo     => 'Todo',
-    vjournal  => 'Journal',
-    vfreebusy => 'FreeBusy',
-    vtimezone => 'TimeZone',
-    standard  => 'TimeZone::Standard',
-    daylight  => 'TimeZone::Daylight',
-);
-
-=head2 parse_object
-
-Translate a L<Text::vFile::asData> sub object into the appropriate 
-L<Data::iCal::Event> subtype.
-
-=cut 
-
-# TODO: this is currently recursive which could blow the stack -
-#       it might be worth refactoring to make it sequential
-sub parse_object {
-    my ( $self, $object ) = @_;
-
-    my $type = $object->{type};
-
-    my $new_self;
-
-    # First check to see if it's generic long name just in case there
-    # event turns out to be a VGENERIC entry type
-    if ( my $class = $_generic{ lc($type) } ) {
-        $new_self = $self->_parse_data_ical_generic( $class, $object );
-
-        # then look for specific overrides
-    } elsif ( my $sub = $self->can( '_parse_' . lc($type) ) ) {
-        $new_self = $self->$sub($object);
-
-        # bitch
-    } else {
-        warn "Can't parse type $type yet";
-        return;
-    }
-
-    # recurse through sub-objects
-    foreach my $sub_object ( @{ $object->{objects} } ) {
-        $new_self->parse_object($sub_object);
-    }
-
-}
-
-# special because we want to use ourselves as the parent
-sub _parse_vcalendar {
-    my ( $self, $object ) = @_;
-    $self->_parse_generic_event( $self, $object );
-    return $self;
-}
-
-# mapping of action types to class (under the Data::Ical::Event::Alarm namespace)
-my %_action_map = (
-    AUDIO     => 'Audio',
-    DISPLAY   => 'Display',
-    EMAIL     => 'Email',
-    PROCEDURE => 'Procedure',
-);
-
-# alarms have actions
-sub _parse_valarm {
-    my ( $parent, $object ) = @_;
-
-    # ick
-    my $action = $object->{properties}->{ACTION}->[0]->{value};
-    die "Can't parse VALARM with action $action"
-        unless exists $_action_map{$action};
-
-    my $alarm_class = "Data::ICal::Entry::Alarm::" . $_action_map{$action};
-    eval "require $alarm_class";
-    die "Failed to require $alarm_class : $@" if $@;
-
-    $alarm_class->import;
-    my $alarm = $alarm_class->new;
-    $parent->_parse_generic_event( $alarm, $object );
-    $parent->add_entry($alarm);
-    return $alarm;
-
-}
-
-# generic event handler
-sub _parse_data_ical_generic {
-    my ( $parent, $class, $object ) = @_;
-
-    my $entry_class = "Data::ICal::Entry::$class";
-    eval "require $entry_class";
-    die "Failed to require $entry_class : $@" if $@;
-
-    $entry_class->import;
-    my $entry = $entry_class->new;
-    $parent->_parse_generic_event( $entry, $object );
-    $parent->add_entry($entry);
-    return $entry;
-}
-
-# handle transferring of properties
-sub _parse_generic_event {
-    my ( $parent, $entry, $object ) = @_;
-
-    my $p = $object->{properties};
-    while ( my ( $key, $val ) = each(%$p) ) {
-        foreach my $occurence (@$val) {
-            my $prop;
-
-            # Unescapes, but only in v2, and not if it's explicitly not TEXT
-            if (not $parent->vcal10
-                and (  not $occurence->{param}
-                    or not defined $occurence->{param}{VALUE}
-                    or $occurence->{param}{VALUE} eq "TEXT" )
-                )
-            {
-                $occurence->{value} =~ s/\\([;,\\])/$1/g;
-                $occurence->{value} =~ s/\\n/\n/ig;
-            }
-            
-            # handle optional params and 'normal' key/value pairs
-            # TODO: line wrapping?
-            if ( $occurence->{param} ) {
-                $prop = [ $occurence->{value}, $occurence->{param} ];
-            } else {
-                $prop = $occurence->{value};
-            }
-            $entry->add_property( lc($key) => $prop );
-        }
-    }
-    return $entry;
+    return 'END:' . $self->ical_entry_type . "\n";
 }
 
 =head1 AUTHOR
 
-Jesse Vincent  C<< <jesse@bestpractical.com> >> with David Glasser and Simon Wistow
+Jesse Vincent  C<< <jesse@bestpractical.com> >>
 
 
 =head1 LICENCE AND COPYRIGHT
